# Markdown

To use this language, use the class "language-markdown".

## Titles

    Title 1
    ==

    Title 2
    -------

    # Title 1
    ## Title 2
    ### Title 3
    #### Title 4
    ##### Title 5
    ###### Title 6

## Bold and italic

    *Italic*
    **Bold on
    multiple lines**
    *Italic on
    multiple lines too*
    __It also works with underscores__
    _It also works with underscores_

    __An empty line

    is not allowed__

## Links

    [Prism](http://www.prismjs.com)
    [Prism](http://www.prismjs.com "Prism")

    [prism link]: http://www.prismjs.com (Prism)
    [Prism] [prism link]

## Lists and quotes

    * This is
    * an unordered list

    1. This is an
    2. ordered list

    * *List item in italic*
    * **List item in bold**
    * [List item as a link](http://example.com "This is an example")

    > This is a quotation
    >> With another quotation inside
    > _italic here_, __bold there__
    > And a [link](http://example.com)

## Code

    Inline code between backticks `<p>Paragraph</p>`

        some_code(); /* Indented
        with four spaces */

    	some_code(); /* Indented
    	with a tab */

## Raw HTML

    > This is a quotation
    > Containing <strong>raw HTML</strong>

    <p>*Italic text inside HTML tag*</p>

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Nesting of elements is not fully supported

    _ **bold** inside italic DOESN'T work _
    __ but *italic* inside bold DOES work __

    [Link partially *italic* DOESN'T work](http://example.com)
    _ [But link inside italic DOES work](http://example.com) _

    [Link partially **bold** DOESN'T work](http://example.com)
    __ [But link inside bold DOES work](http://example.com) __

### Markdown-like HTML attribute

    <p class="_test_"></p>